# pyhc-core

[![PyPI version](https://img.shields.io/pypi/v/pyhc-core.svg?cacheBuster=1)](https://pypi.org/project/pyhc-core/)

`pyhc-core` is a package that simplifies the installation of the core PyHC packages.

## Installation

You can install `pyhc-core` using pip:

```sh
pip install pyhc-core
```

To ensure the latest versions of the core packages are installed, use:
```sh
pip install --upgrade pyhc-core
```

## Core Packages

The following packages are included:
- hapiclient
- kamodo
- plasmapy
- pysat
- pyspedas
- spacepy
- sunpy

## Pip List Table
This table shows the output of running `pip list` after installing `pyhc-core` in a fresh environment (updated nightly):

| Package | Version |
|---------|---------|
| aioftp | 0.22.3 |
| aiohappyeyeballs | 2.4.0 |
| aiohttp | 3.10.5 |
| aiosignal | 1.3.1 |
| aniso8601 | 9.0.1 |
| antlr4-python3-runtime | 4.7 |
| anyio | 4.4.0 |
| argon2-cffi | 23.1.0 |
| argon2-cffi-bindings | 21.2.0 |
| arrow | 1.3.0 |
| asteval | 1.0.2 |
| astropy | 6.1.2 |
| astropy-iers-data | 0.2024.8.27.10.28.29 |
| asttokens | 2.4.1 |
| attrs | 24.2.0 |
| babel | 2.16.0 |
| beautifulsoup4 | 4.12.3 |
| bleach | 6.1.0 |
| blosc2 | 2.7.1 |
| cdasws | 1.8.4 |
| cdflib | 1.3.1 |
| certifi | 2024.7.4 |
| cffi | 1.17.0 |
| cftime | 1.6.4 |
| charset-normalizer | 3.3.2 |
| click | 8.1.7 |
| cloudpickle | 3.0.0 |
| comm | 0.2.2 |
| contourpy | 1.3.0 |
| cryptography | 43.0.0 |
| cycler | 0.12.1 |
| dask | 2024.8.1 |
| debugpy | 1.8.5 |
| decorator | 5.1.1 |
| defusedxml | 0.7.1 |
| dill | 0.3.8 |
| executing | 2.0.1 |
| fastjsonschema | 2.20.0 |
| Flask | 1.1.2 |
| Flask-Cors | 4.0.1 |
| Flask-RESTful | 0.3.8 |
| fonttools | 4.53.1 |
| fqdn | 1.5.1 |
| frozenlist | 1.4.1 |
| fsspec | 2024.6.1 |
| geopack | 1.0.11 |
| h5py | 3.11.0 |
| hapiclient | 0.2.6 |
| hydra-core | 0.11.3 |
| idna | 3.8 |
| importlib_metadata | 8.4.0 |
| incremental | 24.7.2 |
| iniconfig | 2.0.0 |
| ipykernel | 6.29.5 |
| ipython | 8.26.0 |
| ipywidgets | 8.1.5 |
| isodate | 0.6.1 |
| isoduration | 20.11.0 |
| itsdangerous | 2.2.0 |
| jedi | 0.19.1 |
| Jinja2 | 3.1.4 |
| joblib | 1.4.2 |
| json5 | 0.9.25 |
| jsonpointer | 3.0.0 |
| jsonschema | 4.23.0 |
| jsonschema-specifications | 2023.12.1 |
| jupyter_client | 8.6.2 |
| jupyter_core | 5.7.2 |
| jupyter-events | 0.10.0 |
| jupyter_server | 2.14.2 |
| jupyter_server_terminals | 0.5.3 |
| jupyterlab_pygments | 0.3.0 |
| jupyterlab_server | 2.27.3 |
| jupyterlab_widgets | 3.0.13 |
| kamodo | 23.3.0 |
| kiwisolver | 1.4.5 |
| llvmlite | 0.43.0 |
| lmfit | 1.3.2 |
| locket | 1.0.0 |
| MarkupSafe | 2.1.5 |
| matplotlib | 3.9.2 |
| matplotlib-inline | 0.1.7 |
| mistune | 3.0.2 |
| mpmath | 1.3.0 |
| msgpack | 1.0.8 |
| multidict | 6.0.5 |
| nbclient | 0.10.0 |
| nbconvert | 7.16.4 |
| nbformat | 5.10.4 |
| ndindex | 1.8 |
| nest-asyncio | 1.6.0 |
| netCDF4 | 1.7.1.post2 |
| numba | 0.60.0 |
| numexpr | 2.10.1 |
| numpy | 1.26.4 |
| omegaconf | 1.4.1 |
| overrides | 7.7.0 |
| packaging | 24.1 |
| pandas | 2.2.2 |
| pandocfilters | 1.5.1 |
| parfive | 2.1.0 |
| parso | 0.8.4 |
| partd | 1.4.2 |
| pexpect | 4.9.0 |
| pillow | 10.4.0 |
| pip | 24.2 |
| plasmapy | 2024.7.0 |
| platformdirs | 4.2.2 |
| plotly | 5.23.0 |
| pluggy | 1.5.0 |
| portalocker | 2.10.1 |
| prometheus_client | 0.20.0 |
| prompt_toolkit | 3.0.47 |
| psutil | 6.0.0 |
| ptyprocess | 0.7.0 |
| pure_eval | 0.2.3 |
| py-cpuinfo | 9.0.0 |
| pycapnp | 2.0.0 |
| pycparser | 2.22 |
| pyerfa | 2.0.1.4 |
| Pygments | 2.18.0 |
| pyhc-core | 0.0.4 |
| pyOpenSSL | 24.2.1 |
| pyparsing | 3.1.4 |
| pysat | 3.2.0 |
| pyspedas | 1.5.18 |
| pytest | 8.3.2 |
| python-dateutil | 2.9.0.post0 |
| python-forge | 18.6.0 |
| python-json-logger | 2.0.7 |
| pytplot-mpl-temp | 2.2.40 |
| pytz | 2024.1 |
| PyWavelets | 1.7.0 |
| PyYAML | 6.0.2 |
| pyzmq | 26.2.0 |
| referencing | 0.35.1 |
| requests | 2.32.3 |
| rfc3339-validator | 0.1.4 |
| rfc3986-validator | 0.1.1 |
| rpds-py | 0.20.0 |
| scipy | 1.14.1 |
| Send2Trash | 1.8.3 |
| setuptools | 65.5.0 |
| six | 1.16.0 |
| sniffio | 1.3.1 |
| soupsieve | 2.6 |
| spacepy | 0.6.0 |
| stack-data | 0.6.3 |
| sunpy | 6.0.1 |
| sympy | 1.5.1 |
| tables | 3.10.1 |
| tenacity | 9.0.0 |
| terminado | 0.18.1 |
| tinycss2 | 1.3.0 |
| toolz | 0.12.1 |
| tornado | 6.4.1 |
| tqdm | 4.66.5 |
| traitlets | 5.14.3 |
| types-python-dateutil | 2.9.0.20240821 |
| typing_extensions | 4.12.2 |
| tzdata | 2024.1 |
| uncertainties | 3.2.2 |
| uri-template | 1.3.0 |
| urllib3 | 2.2.2 |
| viresclient | 0.12.0 |
| voila | 0.5.7 |
| wcwidth | 0.2.13 |
| webcolors | 24.8.0 |
| webencodings | 0.5.1 |
| websocket-client | 1.8.0 |
| websockets | 13.0 |
| Werkzeug | 3.0.4 |
| widgetsnbextension | 4.0.13 |
| wrapt | 1.16.0 |
| xarray | 2024.7.0 |
| yarl | 1.9.4 |
| zipp | 3.20.1 |
